from json import loads
from json.decoder import JSONDecodeError

def _formatRecord(record, meta):
    r = {}
    i = 0
    values = [None if list(field.keys())[0] == 'isNull' and list(field.values())[0] else list(field.values())[0] for field in record]
    for value in values:
        try:
            value = loads(value)
        except (JSONDecodeError, TypeError):
            pass
        r[meta[i]["name"]] = value
        i += 1
    return r

# Formatting query returned Field
def parseResults(results):
    response = []
    if "columnMetadata" not in results:
        raise Exception("Query results must include columnMetada")
    for record in ("records" in results and results["records"]) or []:
        response.append(_formatRecord(record, results["columnMetadata"]))
    return response



import io
from setuptools import setup


setup(
    name='aurora-prettyparser',
    version='1.0.0',
    description='Parses Aurora responses into a list dictionaries with column names as keys',
    author='Mathew Moon',
    author_email='mmoon@quinovas.com',
    url='https://github.com/QuiNovas/aurora-prettyparser',
    license='Apache 2.0',
    long_description=io.open('README.rst', encoding='utf-8').read(),
    long_description_content_type='text/x-rst',
    packages=['auroraPrettyParser'],
    package_dir={'auroraPrettyParser': 'src/auroraPrettyParser'},
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.7',
    ],
)
